@@ -1,3 +1,4 @@
+import { takeUntil } from "rxjs/operators";
 import { Component, OnInit } from "@angular/core";
 import { BalloonMsgService, HeaderService } from "@synerty/peek-plugin-base-js";
 import { NgLifeCycleEvents } from "@synerty/vortexjs";
@@ -7,7 +8,7 @@ import {
     DeviceTupleService,
     ServerInfoTuple,
 } from "@peek/peek_core_device/_private";
-import { DeviceTypeEnum } from "@peek/peek_core_device/_private/hardware-info/hardware-info";
+import { DeviceTypeEnum } from "@peek/peek_core_device/_private/hardware-info/hardware-info.abstract";
 import { Capacitor } from "@capacitor/core";
 
 @Component({
@@ -17,7 +18,7 @@ import { Capacitor } from "@capacitor/core";
 export class ConnectComponent extends NgLifeCycleEvents implements OnInit {
     server: ServerInfoTuple = new ServerInfoTuple();
     httpPortStr: string = "8000";
-    websocketPortStr: string = "8000";
+    websocketPortStr: string = "8001";
     deviceType: DeviceTypeEnum;
     isWeb: boolean;
     platform: string;
@@ -35,14 +36,14 @@ export class ConnectComponent extends NgLifeCycleEvents implements OnInit {
         this.isWeb = this.tupleService.hardwareInfo.isWeb();
 
         this.deviceServerService.connInfoObserver
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((info: ServerInfoTuple) => {
                 this.server = info;
             });
 
         // Make sure we're not on this page when things are fine.
         let sub = this.doCheckEvent
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => {
                 if (this.deviceServerService.isConnected) {
                     this.nav.toEnroll();
