@@ -1,7 +1,7 @@
-import { CommonModule } from "@angular/common"
-import { NgModule } from "@angular/core"
+import { CommonModule } from "@angular/common";
+import { NgModule } from "@angular/core";
 // Import the default route component
-import { DeviceComponent } from "./device.component"
+import { DeviceComponent } from "./device.component";
 // Import the required classes from VortexJS
 import {
     TupleActionPushNameService,
@@ -12,38 +12,38 @@ import {
     TupleDataOfflineObserverService,
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
-} from "@synerty/vortexjs"
+} from "@synerty/vortexjs";
 // Import the names we need for the
 import {
     deviceFilt,
     deviceObservableName,
     deviceTupleOfflineServiceName,
-} from "@peek/peek_core_device/_private/PluginNames"
-import { EnrollComponent } from "./enroll/enroll.component"
+} from "@peek/peek_core_device/_private/PluginNames";
+import { EnrollComponent } from "./enroll/enroll.component";
 // Import the names we need for the
-import { deviceActionProcessorName } from "@peek/peek_core_device/_private"
-import { EnrollingComponent } from "./enrolling/enrolling.component"
-import { ConnectComponent } from "./connect/connect.component"
-import { ConnectingComponent } from "./connecting/connecting.component"
-import { pluginRoutes } from "./device.routes"
-import { FormsModule } from "@angular/forms"
-import { NzIconModule } from "ng-zorro-antd/icon"
-import { RouterModule } from "@angular/router"
-import { HttpClientModule } from "@angular/common/http"
+import { deviceActionProcessorName } from "@peek/peek_core_device/_private";
+import { EnrollingComponent } from "./enrolling/enrolling.component";
+import { ConnectComponent } from "./connect/connect.component";
+import { ConnectingComponent } from "./connecting/connecting.component";
+import { pluginRoutes } from "./device.routes";
+import { FormsModule } from "@angular/forms";
+import { NzIconModule } from "ng-zorro-antd/icon";
+import { RouterModule } from "@angular/router";
+import { HttpClientModule } from "@angular/common/http";
 
 export function tupleActionPushNameServiceFactory() {
     return new TupleActionPushNameService(
         deviceActionProcessorName,
         deviceFilt
-    )
+    );
 }
 
 export function tupleDataObservableNameServiceFactory() {
-    return new TupleDataObservableNameService(deviceObservableName, deviceFilt)
+    return new TupleDataObservableNameService(deviceObservableName, deviceFilt);
 }
 
 export function tupleOfflineStorageNameServiceFactory() {
-    return new TupleOfflineStorageNameService(deviceTupleOfflineServiceName)
+    return new TupleOfflineStorageNameService(deviceTupleOfflineServiceName);
 }
 
 // Define the root module for this plugin.
@@ -85,5 +85,4 @@ export function tupleOfflineStorageNameServiceFactory() {
         ConnectingComponent,
     ],
 })
-export class DeviceModule {
-}
+export class DeviceModule {}
