@@ -2,9 +2,15 @@ from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
 
 from peek_core_device._private.PluginNames import deviceFilt
 from peek_core_device._private.PluginNames import deviceObservableName
+from peek_core_device._private.server.controller.OfflineCacheController import (
+    OfflineCacheController,
+)
 from peek_core_device._private.server.tuple_providers.ClientSettingsTupleProvider import (
     ClientSettingsTupleProvider,
 )
+from peek_core_device._private.server.tuple_providers.DeviceCacheStatusTupleProvider import (
+    DeviceCacheStatusTupleProvider,
+)
 from peek_core_device._private.server.tuple_providers.DeviceGpsLocationTupleProvider import (
     DeviceGpsLocationTupleProvider,
 )
@@ -17,6 +23,9 @@ from peek_core_device._private.server.tuple_providers.DeviceInfoTupleProvider im
 from peek_core_device._private.server.tuple_providers.DeviceUpdateTupleProvider import (
     DeviceUpdateTupleProvider,
 )
+from peek_core_device._private.server.tuple_providers.OfflineCacheSettingTupleProvider import (
+    OfflineCacheSettingTupleProvider,
+)
 from peek_core_device._private.storage.DeviceInfoTable import DeviceInfoTable
 from peek_core_device._private.storage.DeviceUpdateTuple import (
     DeviceUpdateTuple,
@@ -24,19 +33,28 @@ from peek_core_device._private.storage.DeviceUpdateTuple import (
 from peek_core_device._private.tuples.ClientSettingsTuple import (
     ClientSettingsTuple,
 )
+from peek_core_device._private.tuples.DeviceCacheStatusTuple import (
+    DeviceCacheStatusTuple,
+)
+from peek_core_device._private.tuples.OfflineCacheSettingTuple import (
+    OfflineCacheSettingTuple,
+)
 from peek_core_device.tuples.DeviceGpsLocationTuple import (
     DeviceGpsLocationTuple,
 )
 from peek_core_device.tuples.DeviceInfoTuple import DeviceInfoTuple
 
 
-def makeTupleDataObservableHandler(ormSessionCreator):
+def makeTupleDataObservableHandler(
+    ormSessionCreator, offlineCacheController: OfflineCacheController
+):
     """ " Make Tuple Data Observable Handler
 
     This method creates the observable object, registers the tuple providers and then
     returns it.
 
     :param ormSessionCreator: A function that returns a SQLAlchemy session when called
+    :param offlineCacheController:
 
     :return: An instance of :code:`TupleDataObservableHandler`
 
@@ -52,7 +70,13 @@ def makeTupleDataObservableHandler(ormSessionCreator):
     )
 
     tupleObservable.addTupleProvider(
-        DeviceInfoTuple.tupleName(), DeviceInfoTupleProvider(ormSessionCreator)
+        DeviceInfoTuple.tupleName(),
+        DeviceInfoTupleProvider(ormSessionCreator, offlineCacheController),
+    )
+
+    tupleObservable.addTupleProvider(
+        DeviceCacheStatusTuple.tupleName(),
+        DeviceCacheStatusTupleProvider(offlineCacheController),
     )
 
     tupleObservable.addTupleProvider(
@@ -70,4 +94,9 @@ def makeTupleDataObservableHandler(ormSessionCreator):
         DeviceGpsLocationTupleProvider(ormSessionCreator),
     )
 
+    tupleObservable.addTupleProvider(
+        OfflineCacheSettingTuple.tupleName(),
+        OfflineCacheSettingTupleProvider(ormSessionCreator),
+    )
+
     return tupleObservable
