@@ -1,19 +1,22 @@
 from typing import Optional
 
-from peek_core_device._private.PluginNames import deviceTuplePrefix
-from vortex.Tuple import addTupleType, TupleField
+from vortex.Tuple import TupleField
+from vortex.Tuple import addTupleType
 from vortex.TupleAction import TupleActionABC
 
+from peek_core_device._private.PluginNames import deviceTuplePrefix
+
 
 # I'm using the word Alter here, because UpdateUpdate is confusing.
 @addTupleType
 class AlterDeviceUpdateAction(TupleActionABC):
-    """ Alter Device Update Tuple
+    """Alter Device Update Tuple
 
     This action tuple applies changes to the Update from the admin UI.
 
     """
-    __tupleType__ = deviceTuplePrefix + 'AlterDeviceUpdateAction'
+
+    __tupleType__ = deviceTuplePrefix + "AlterDeviceUpdateAction"
 
     #:  the ID of the DeviceUpdateTuple
     updateId: int = TupleField()
@@ -22,4 +25,4 @@ class AlterDeviceUpdateAction(TupleActionABC):
     isEnabled: Optional[bool] = TupleField()
 
     #: Delete the update from the database
-    remove: bool = TupleField(False)
\ No newline at end of file
+    remove: bool = TupleField(False)
