@@ -1,6 +1,6 @@
 import { addTupleType, Tuple } from "@synerty/vortexjs";
 import { deviceTuplePrefix } from "./_private/PluginNames";
-import { DeviceTypeEnum } from "./_private/hardware-info/hardware-info";
+import { DeviceTypeEnum } from "./_private/hardware-info/hardware-info.abstract";
 import { DeviceGpsLocationTuple } from "./DeviceGpsLocationTuple";
 import { Capacitor } from "@capacitor/core";
 
