@@ -5,20 +5,17 @@ import {
     DeviceGpsLocationTuple,
 } from "@peek/peek_core_device";
 import { UserService } from "@peek/peek_core_user";
-import { Capacitor } from "@capacitor/core";
+import { Capacitor, Plugins } from "@capacitor/core";
 import { DeviceTupleService } from "../device-tuple.service";
 import { GpsLocationUpdateTupleAction } from "./GpsLocationUpdateTupleAction";
 import { DeviceEnrolmentService } from "../../device-enrolment.service";
 import { DeviceBackgroundService } from "../device-background.service";
-import { Geolocation } from "@capacitor/geolocation";
-import { Dialog } from "@capacitor/dialog";
-import { isField } from "../hardware-info/is-field.mweb";
-
-import { registerPlugin } from "@capacitor/core";
 import { BackgroundGeolocationPlugin } from "@capacitor-community/background-geolocation";
-const BackgroundGeolocation = registerPlugin<BackgroundGeolocationPlugin>(
-    "BackgroundGeolocation"
-);
+
+const BackgroundGeolocation =
+    Plugins.BackgroundGeolocation as BackgroundGeolocationPlugin;
+
+const { Geolocation, Modals } = Plugins;
 
 @Injectable()
 export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
@@ -36,22 +33,20 @@ export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
     ) {
         super();
 
-        if (isField) {
-            combineLatest(
-                this.userService.loggedInStatus,
-                this.deviceService.deviceInfoObservable()
-            ).subscribe(async ([isLoggedIn, deviceInfo]) => {
-                if (isLoggedIn && deviceInfo.isEnrolled) {
-                    if (!this.gpsWatchId) {
-                        this.startLocationListener();
-                    }
-                } else {
-                    if (this.gpsWatchId) {
-                        this.stopLocationListener();
-                    }
+        combineLatest(
+            this.userService.loggedInStatus,
+            this.deviceService.deviceInfoObservable()
+        ).subscribe(async ([isLoggedIn, deviceInfo]) => {
+            if (isLoggedIn && deviceInfo.isEnrolled) {
+                if (!this.gpsWatchId) {
+                    this.startLocationListener();
                 }
-            });
-        }
+            } else {
+                if (this.gpsWatchId) {
+                    this.stopLocationListener();
+                }
+            }
+        });
     }
 
     get location$(): Observable<DeviceGpsLocationTuple | null> {
@@ -72,7 +67,7 @@ export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
 
     private startLocationListener(): void {
         if (Capacitor.isNative) {
-            BackgroundGeolocation.addWatcher(
+            this.gpsWatchId = BackgroundGeolocation.addWatcher(
                 {
                     backgroundMessage:
                         "Allow Peek track this devices GPS location.",
@@ -92,8 +87,7 @@ export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
                         this.updateLocation({ coords });
                     }
                 }
-            ) //
-                .then((gpsWatchId) => (this.gpsWatchId = gpsWatchId));
+            );
         } else {
             Geolocation.getCurrentPosition()
                 .then((position) => {
@@ -105,20 +99,19 @@ export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
                     console.log("Cannot get current GPS position.");
                 });
 
-            Geolocation.watchPosition(
+            this.gpsWatchId = Geolocation.watchPosition(
                 { enableHighAccuracy: true },
                 (position, err) => {
                     if (position) {
                         this.updateLocation(position);
                     }
                 }
-            ) //
-                .then((gpsWatchId) => (this.gpsWatchId = gpsWatchId));
+            );
         }
     }
 
     private handleLocationPermission(): void {
-        Dialog.confirm({
+        Modals.confirm({
             title: "Location Required",
             message:
                 "This app needs your location, " +
@@ -132,15 +125,12 @@ export class PrivateDeviceGpsLocationService extends DeviceGpsLocationService {
     }
 
     private stopLocationListener(): void {
-        if (Capacitor.isNativePlatform()) {
-            BackgroundGeolocation.removeWatcher({
-                id: this.gpsWatchId,
-            });
-            this.gpsWatchId = null;
+        if (Capacitor.isNative) {
+            BackgroundGeolocation.removeWatcher({ id: this.gpsWatchId });
         } else {
-            Geolocation.clearWatch({ id: this.gpsWatchId }) //
-                .then(() => (this.gpsWatchId = null));
+            Geolocation.clearWatch({ id: this.gpsWatchId });
         }
+        this.gpsWatchId = null;
     }
 
     private updateLocation(position): void {
